# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_information_service.api_client import ApiClient
from dhicn_model_information_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ModelEditApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_model_information_boundary_list_get(self, **kwargs):  # noqa: E501
        """获取所有的模型边界信息 Get all model boundaries  # noqa: E501

        获取所有的降雨、河道水位、流量、工业点源排放流量等边界列表 Get all the rainfall, river water level, river discharge or industry point source wastewater discharge boundaries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_list_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str boundary_type: 边界类型 boundary type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GetAllBoundarysOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_list_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_list_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的模型边界信息 Get all model boundaries  # noqa: E501

        获取所有的降雨、河道水位、流量、工业点源排放流量等边界列表 Get all the rainfall, river water level, river discharge or industry point source wastewater discharge boundaries.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_list_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str boundary_type: 边界类型 boundary type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GetAllBoundarysOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'boundary_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'boundary_type' in local_var_params and local_var_params['boundary_type'] is not None:  # noqa: E501
            query_params.append(('boundaryType', local_var_params['boundary_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetAllBoundarysOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_boundary_timeseries_add_post(self, **kwargs):  # noqa: E501
        """批量保存边界时间序列数据 Batch save boundary time series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ModelProcessBoundaryConditionDocument] model_process_boundary_condition_document:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_timeseries_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_timeseries_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量保存边界时间序列数据 Batch save boundary time series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ModelProcessBoundaryConditionDocument] model_process_boundary_condition_document:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_process_boundary_condition_document'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_timeseries_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_process_boundary_condition_document' in local_var_params:
            body_params = local_var_params['model_process_boundary_condition_document']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/timeseries/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_boundary_timeseries_get(self, **kwargs):  # noqa: E501
        """获取方案的边界时间序列数据 Get boundary time series data of a scenario  # noqa: E501

        获取降雨、河道水位、流量、工业点源排放流量等边界时间序列数据 Get rainfall, river water level, river discharge or industry point source wastewater discharge boundary's time series data of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str boundary_id: 边界ID boundary id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetBoundaryTsOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_timeseries_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_timeseries_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取方案的边界时间序列数据 Get boundary time series data of a scenario  # noqa: E501

        获取降雨、河道水位、流量、工业点源排放流量等边界时间序列数据 Get rainfall, river water level, river discharge or industry point source wastewater discharge boundary's time series data of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str boundary_id: 边界ID boundary id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetBoundaryTsOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'boundary_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'boundary_id' in local_var_params and local_var_params['boundary_id'] is not None:  # noqa: E501
            query_params.append(('boundaryID', local_var_params['boundary_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetBoundaryTsOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_boundary_timeseries_update_post(self, **kwargs):  # noqa: E501
        """设置方案的边界时间序列数据 Set boundary time series data of a scenario  # noqa: E501

        设置降雨、河道水位、流量、工业点源排放流量等边界时间序列数据 Set rainfall, river water level, river discharge or industry point source wastewater discharge boundary's time series data of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateBoundaryTsInput update_boundary_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_timeseries_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_timeseries_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """设置方案的边界时间序列数据 Set boundary time series data of a scenario  # noqa: E501

        设置降雨、河道水位、流量、工业点源排放流量等边界时间序列数据 Set rainfall, river water level, river discharge or industry point source wastewater discharge boundary's time series data of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_timeseries_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateBoundaryTsInput update_boundary_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_boundary_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_timeseries_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_boundary_ts_input' in local_var_params:
            body_params = local_var_params['update_boundary_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/timeseries/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_boundary_wastewater_get(self, **kwargs):  # noqa: E501
        """获取方案的污水量数据 Get wastewater data of a scenario.  # noqa: E501

        获取生活面源污水数据，包括汇水区单位面积排放量、流量模式等 Get domestic distributed source wastewater data, including catchment discharge per area and pattern of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_wastewater_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str boundary_id: 边界ID boundary id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetWasteWaterConditionOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_wastewater_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_wastewater_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取方案的污水量数据 Get wastewater data of a scenario.  # noqa: E501

        获取生活面源污水数据，包括汇水区单位面积排放量、流量模式等 Get domestic distributed source wastewater data, including catchment discharge per area and pattern of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_wastewater_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str boundary_id: 边界ID boundary id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetWasteWaterConditionOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'boundary_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_wastewater_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'boundary_id' in local_var_params and local_var_params['boundary_id'] is not None:  # noqa: E501
            query_params.append(('boundaryId', local_var_params['boundary_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/wastewater', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetWasteWaterConditionOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_boundary_wastewater_update_post(self, **kwargs):  # noqa: E501
        """设置方案的污水量数据 Set wastewater data of a scenario  # noqa: E501

        设置生活面源污水数据，包括汇水区单位面积排放量、流量模式等 Set domestic distributed source wastewater data, including catchment discharge per area and pattern of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_wastewater_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateWastWaterConditionInput update_wast_water_condition_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_boundary_wastewater_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_boundary_wastewater_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """设置方案的污水量数据 Set wastewater data of a scenario  # noqa: E501

        设置生活面源污水数据，包括汇水区单位面积排放量、流量模式等 Set domestic distributed source wastewater data, including catchment discharge per area and pattern of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_boundary_wastewater_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateWastWaterConditionInput update_wast_water_condition_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_wast_water_condition_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_boundary_wastewater_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_wast_water_condition_input' in local_var_params:
            body_params = local_var_params['update_wast_water_condition_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/boundary/wastewater/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_control_rule_get(self, **kwargs):  # noqa: E501
        """获取方案的调度规则数据 Get control rule data of a scenario  # noqa: E501

        获取调度规则数据，包括河道泵站控制水位、能力，河道闸门控制水位，管网泵站开启水位、停止水位、能力，管网阀门开度等 Get control rule data including river pump control water level and capacity; river gate control water level; network pump start water level, stop water level, capacity; network valve openning of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_control_rule_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetControlRuleByScenarioOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_control_rule_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_control_rule_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取方案的调度规则数据 Get control rule data of a scenario  # noqa: E501

        获取调度规则数据，包括河道泵站控制水位、能力，河道闸门控制水位，管网泵站开启水位、停止水位、能力，管网阀门开度等 Get control rule data including river pump control water level and capacity; river gate control water level; network pump start water level, stop water level, capacity; network valve openning of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_control_rule_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetControlRuleByScenarioOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_control_rule_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/control-rule', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetControlRuleByScenarioOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_control_rule_update_post(self, **kwargs):  # noqa: E501
        """设置方案的调度规则数据 Set control rule data of a scenario  # noqa: E501

        设置调度规则数据，包括河道泵站控制水位、能力，河道闸门控制水位，管网泵站开启水位、停止水位、能力，管网阀门开度等 Set control rule data including river pump control water level and capacity; river gate control water level; network pump start water level, stop water level, capacity; network valve openning of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_control_rule_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlRuleInput update_control_rule_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_control_rule_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_control_rule_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """设置方案的调度规则数据 Set control rule data of a scenario  # noqa: E501

        设置调度规则数据，包括河道泵站控制水位、能力，河道闸门控制水位，管网泵站开启水位、停止水位、能力，管网阀门开度等 Set control rule data including river pump control water level and capacity; river gate control water level; network pump start water level, stop water level, capacity; network valve openning of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_control_rule_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlRuleInput update_control_rule_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_control_rule_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_control_rule_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_control_rule_input' in local_var_params:
            body_params = local_var_params['update_control_rule_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/control-rule/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_initial_condition_hotstart_get(self, **kwargs):  # noqa: E501
        """获取方案的热启动信息 Get initial condition hotstart information of a scenario  # noqa: E501

        获取方案的热启动信息，包括热启动方案、热启动文件名称等 Get initial condition hotstart information, including hotstart scenario id, hotstart file name, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_initial_condition_hotstart_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: scenario's ID
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetInitialConditionOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_initial_condition_hotstart_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_initial_condition_hotstart_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取方案的热启动信息 Get initial condition hotstart information of a scenario  # noqa: E501

        获取方案的热启动信息，包括热启动方案、热启动文件名称等 Get initial condition hotstart information, including hotstart scenario id, hotstart file name, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_initial_condition_hotstart_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: scenario's ID
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetInitialConditionOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_initial_condition_hotstart_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/initial-condition/hotstart', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetInitialConditionOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_initial_condition_hotstart_update_post(self, **kwargs):  # noqa: E501
        """设置方案的热启动信息 Set initial condition hotstart information of a scenario  # noqa: E501

        设置方案的热启动信息，包括热启动方案、热启动文件名称等 Set initial condition hotstart information, including hotstart scenario id, hotstart file name, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_initial_condition_hotstart_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateInitialConditionInput update_initial_condition_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_initial_condition_hotstart_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_initial_condition_hotstart_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """设置方案的热启动信息 Set initial condition hotstart information of a scenario  # noqa: E501

        设置方案的热启动信息，包括热启动方案、热启动文件名称等 Set initial condition hotstart information, including hotstart scenario id, hotstart file name, etc. of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_initial_condition_hotstart_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateInitialConditionInput update_initial_condition_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_initial_condition_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_initial_condition_hotstart_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_initial_condition_input' in local_var_params:
            body_params = local_var_params['update_initial_condition_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/initial-condition/hotstart/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class AddOrificeResultInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'compute_type': 'str',
        'factory_code': 'str',
        'opened_num': 'int',
        'opened_height': 'float'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'compute_type': 'computeType',
        'factory_code': 'factoryCode',
        'opened_num': 'openedNum',
        'opened_height': 'openedHeight'
    }

    def __init__(self, scenario_id=None, compute_type=None, factory_code=None, opened_num=None, opened_height=None, local_vars_configuration=None):  # noqa: E501
        """AddOrificeResultInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._compute_type = None
        self._factory_code = None
        self._opened_num = None
        self._opened_height = None
        self.discriminator = None

        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.compute_type = compute_type
        self.factory_code = factory_code
        if opened_num is not None:
            self.opened_num = opened_num
        if opened_height is not None:
            self.opened_height = opened_height

    @property
    def scenario_id(self):
        """Gets the scenario_id of this AddOrificeResultInput.  # noqa: E501


        :return: The scenario_id of this AddOrificeResultInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this AddOrificeResultInput.


        :param scenario_id: The scenario_id of this AddOrificeResultInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def compute_type(self):
        """Gets the compute_type of this AddOrificeResultInput.  # noqa: E501

        drySeason-旱季  # noqa: E501

        :return: The compute_type of this AddOrificeResultInput.  # noqa: E501
        :rtype: str
        """
        return self._compute_type

    @compute_type.setter
    def compute_type(self, compute_type):
        """Sets the compute_type of this AddOrificeResultInput.

        drySeason-旱季  # noqa: E501

        :param compute_type: The compute_type of this AddOrificeResultInput.  # noqa: E501
        :type: str
        """

        self._compute_type = compute_type

    @property
    def factory_code(self):
        """Gets the factory_code of this AddOrificeResultInput.  # noqa: E501

        厂区编码  # noqa: E501

        :return: The factory_code of this AddOrificeResultInput.  # noqa: E501
        :rtype: str
        """
        return self._factory_code

    @factory_code.setter
    def factory_code(self, factory_code):
        """Sets the factory_code of this AddOrificeResultInput.

        厂区编码  # noqa: E501

        :param factory_code: The factory_code of this AddOrificeResultInput.  # noqa: E501
        :type: str
        """

        self._factory_code = factory_code

    @property
    def opened_num(self):
        """Gets the opened_num of this AddOrificeResultInput.  # noqa: E501

        各厂的开堰数  # noqa: E501

        :return: The opened_num of this AddOrificeResultInput.  # noqa: E501
        :rtype: int
        """
        return self._opened_num

    @opened_num.setter
    def opened_num(self, opened_num):
        """Sets the opened_num of this AddOrificeResultInput.

        各厂的开堰数  # noqa: E501

        :param opened_num: The opened_num of this AddOrificeResultInput.  # noqa: E501
        :type: int
        """

        self._opened_num = opened_num

    @property
    def opened_height(self):
        """Gets the opened_height of this AddOrificeResultInput.  # noqa: E501

        各厂常开固定堰高度  # noqa: E501

        :return: The opened_height of this AddOrificeResultInput.  # noqa: E501
        :rtype: float
        """
        return self._opened_height

    @opened_height.setter
    def opened_height(self, opened_height):
        """Sets the opened_height of this AddOrificeResultInput.

        各厂常开固定堰高度  # noqa: E501

        :param opened_height: The opened_height of this AddOrificeResultInput.  # noqa: E501
        :type: float
        """

        self._opened_height = opened_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddOrificeResultInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddOrificeResultInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_identity_service.api_client import ApiClient
from dhicn_identity_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MenuPerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_app_menu_per_button_per_post(self, **kwargs):  # noqa: E501
        """添加按钮权限 Add button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddButtonPerInput add_button_per_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_button_per_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_button_per_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加按钮权限 Add button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddButtonPerInput add_button_per_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_button_per_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_button_per_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_button_per_input' in local_var_params:
            body_params = local_var_params['add_button_per_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/buttonPer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_button_per_put(self, **kwargs):  # noqa: E501
        """更新按钮权限 Update button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateButtonPerInput update_button_per_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_button_per_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_button_per_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新按钮权限 Update button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateButtonPerInput update_button_per_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_button_per_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_button_per_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_button_per_input' in local_var_params:
            body_params = local_var_params['update_button_per_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/buttonPer', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_button_per_under_role_post(self, **kwargs):  # noqa: E501
        """角色所拥有的按钮权限 Button permissions of role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_under_role_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ButtonPerUnderRoleInput button_per_under_role_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ButtonPer]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_button_per_under_role_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_button_per_under_role_post_with_http_info(self, **kwargs):  # noqa: E501
        """角色所拥有的按钮权限 Button permissions of role  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_per_under_role_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ButtonPerUnderRoleInput button_per_under_role_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ButtonPer], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'button_per_under_role_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_button_per_under_role_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'button_per_under_role_input' in local_var_params:
            body_params = local_var_params['button_per_under_role_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/buttonPerUnderRole', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ButtonPer]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_button_pers_under_menu_post(self, **kwargs):  # noqa: E501
        """获取菜单下的按钮权限 Get button permissions under the menu  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_pers_under_menu_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ButtonPerUnderMenuInput button_per_under_menu_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ButtonPerUnderMenuOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_button_pers_under_menu_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_button_pers_under_menu_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取菜单下的按钮权限 Get button permissions under the menu  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_button_pers_under_menu_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ButtonPerUnderMenuInput button_per_under_menu_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ButtonPerUnderMenuOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'button_per_under_menu_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_button_pers_under_menu_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'button_per_under_menu_input' in local_var_params:
            body_params = local_var_params['button_per_under_menu_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/buttonPersUnderMenu', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ButtonPerUnderMenuOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_copy_menu_per_post(self, **kwargs):  # noqa: E501
        """/api/app/menuPer/copyMenuPer  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_copy_menu_per_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CopyMenuInput copy_menu_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_copy_menu_per_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_copy_menu_per_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/app/menuPer/copyMenuPer  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_copy_menu_per_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CopyMenuInput copy_menu_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'copy_menu_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_copy_menu_per_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'copy_menu_input' in local_var_params:
            body_params = local_var_params['copy_menu_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/copyMenuPer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_grant_per_post(self, **kwargs):  # noqa: E501
        """赋予角色权限 Grant role permissions  # noqa: E501

        整体权限赋值,旧的会被新的全覆盖 old permission of the role will be overall overrided  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_grant_per_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GrantPerInput grant_per_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_grant_per_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_grant_per_post_with_http_info(self, **kwargs):  # noqa: E501
        """赋予角色权限 Grant role permissions  # noqa: E501

        整体权限赋值,旧的会被新的全覆盖 old permission of the role will be overall overrided  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_grant_per_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GrantPerInput grant_per_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'grant_per_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_grant_per_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'grant_per_input' in local_var_params:
            body_params = local_var_params['grant_per_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/grantPer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_id_per_details_get(self, id, **kwargs):  # noqa: E501
        """获取权限详细信息 Get permission details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_id_per_details_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 权限ID permission id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PerDetailsOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_id_per_details_get_with_http_info(id, **kwargs)  # noqa: E501

    def api_app_menu_per_id_per_details_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """获取权限详细信息 Get permission details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_id_per_details_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 权限ID permission id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PerDetailsOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_id_per_details_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `api_app_menu_per_id_per_details_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/{id}/perDetails', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PerDetailsOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_menu_per_post(self, **kwargs):  # noqa: E501
        """添加菜单权限 Add menu permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_per_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMenuInput add_menu_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_menu_per_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_menu_per_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加菜单权限 Add menu permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_per_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMenuInput add_menu_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_menu_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_menu_per_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_menu_input' in local_var_params:
            body_params = local_var_params['add_menu_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/menuPer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_menu_per_put(self, **kwargs):  # noqa: E501
        """更新菜单权限 Update menu permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_per_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateMenuInput update_menu_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_menu_per_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_menu_per_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新菜单权限 Update menu permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_per_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateMenuInput update_menu_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_menu_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_menu_per_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_menu_input' in local_var_params:
            body_params = local_var_params['update_menu_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/menuPer', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_menu_pers_tree_system_id_post(self, system_id, **kwargs):  # noqa: E501
        """获取系统的菜单权限树 Get the menu permission tree of the system  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_pers_tree_system_id_post(system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str system_id: 系统ID system id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MenuPerTree]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_menu_pers_tree_system_id_post_with_http_info(system_id, **kwargs)  # noqa: E501

    def api_app_menu_per_menu_pers_tree_system_id_post_with_http_info(self, system_id, **kwargs):  # noqa: E501
        """获取系统的菜单权限树 Get the menu permission tree of the system  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_pers_tree_system_id_post_with_http_info(system_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str system_id: 系统ID system id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MenuPerTree], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'system_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_menu_pers_tree_system_id_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'system_id' is set
        if self.api_client.client_side_validation and ('system_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['system_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `system_id` when calling `api_app_menu_per_menu_pers_tree_system_id_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'system_id' in local_var_params:
            path_params['systemId'] = local_var_params['system_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/menuPersTree/{systemId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MenuPerTree]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_menu_pers_under_role_role_id_post(self, role_id, **kwargs):  # noqa: E501
        """角色所拥有的菜单权限 Menu permissions of role  # noqa: E501

        已经拥有的菜单/按钮权限（IsCheck = true） already owned menu / button permissions (IsCheck = true)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_pers_under_role_role_id_post(role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str role_id: 角色ID role id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MenuPerTree]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_menu_pers_under_role_role_id_post_with_http_info(role_id, **kwargs)  # noqa: E501

    def api_app_menu_per_menu_pers_under_role_role_id_post_with_http_info(self, role_id, **kwargs):  # noqa: E501
        """角色所拥有的菜单权限 Menu permissions of role  # noqa: E501

        已经拥有的菜单/按钮权限（IsCheck = true） already owned menu / button permissions (IsCheck = true)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_menu_pers_under_role_role_id_post_with_http_info(role_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str role_id: 角色ID role id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MenuPerTree], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'role_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_menu_pers_under_role_role_id_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'role_id' is set
        if self.api_client.client_side_validation and ('role_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['role_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `role_id` when calling `api_app_menu_per_menu_pers_under_role_role_id_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'role_id' in local_var_params:
            path_params['roleId'] = local_var_params['role_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/menuPersUnderRole/{roleId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MenuPerTree]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_per_detail_under_role_post(self, **kwargs):  # noqa: E501
        """角色拥有的权限明细  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_per_detail_under_role_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PermissionTree]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_per_detail_under_role_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_menu_per_per_detail_under_role_post_with_http_info(self, **kwargs):  # noqa: E501
        """角色拥有的权限明细  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_per_detail_under_role_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PermissionTree], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_per_detail_under_role_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/perDetailUnderRole', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PermissionTree]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_menu_per_per_per_id_delete(self, per_id, **kwargs):  # noqa: E501
        """删除菜单/按钮权限 Delete menu / button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_per_per_id_delete(per_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str per_id: 权限ID permission id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_menu_per_per_per_id_delete_with_http_info(per_id, **kwargs)  # noqa: E501

    def api_app_menu_per_per_per_id_delete_with_http_info(self, per_id, **kwargs):  # noqa: E501
        """删除菜单/按钮权限 Delete menu / button permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_menu_per_per_per_id_delete_with_http_info(per_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str per_id: 权限ID permission id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'per_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_menu_per_per_per_id_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'per_id' is set
        if self.api_client.client_side_validation and ('per_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['per_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `per_id` when calling `api_app_menu_per_per_per_id_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'per_id' in local_var_params:
            path_params['perId'] = local_var_params['per_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/menuPer/per/{perId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_identity_service.api.connect_api import ConnectApi
from dhicn_identity_service.api.files_api import FilesApi
from dhicn_identity_service.api.login_api import LoginApi
from dhicn_identity_service.api.menu_per_api import MenuPerApi
from dhicn_identity_service.api.micro_services_manager_api import MicroServicesManagerApi
from dhicn_identity_service.api.organization_mananger_api import OrganizationManangerApi
from dhicn_identity_service.api.personal_center_api import PersonalCenterApi
from dhicn_identity_service.api.role_manager_api import RoleManagerApi
from dhicn_identity_service.api.rpc_oper_api import RpcOperApi
from dhicn_identity_service.api.tenant_manager_api import TenantManagerApi
from dhicn_identity_service.api.user_status_api import UserStatusApi
from dhicn_identity_service.api.users_mnanger_api import UsersMnangerApi



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class IotGroupConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'group_name': 'str',
        'level_code': 'str',
        'parent_level_code': 'str'
    }

    attribute_map = {
        'id': 'id',
        'group_name': 'groupName',
        'level_code': 'levelCode',
        'parent_level_code': 'parentLevelCode'
    }

    def __init__(self, id=None, group_name=None, level_code=None, parent_level_code=None, local_vars_configuration=None):  # noqa: E501
        """IotGroupConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._group_name = None
        self._level_code = None
        self._parent_level_code = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.group_name = group_name
        self.level_code = level_code
        self.parent_level_code = parent_level_code

    @property
    def id(self):
        """Gets the id of this IotGroupConfigOutput.  # noqa: E501

        Id  # noqa: E501

        :return: The id of this IotGroupConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IotGroupConfigOutput.

        Id  # noqa: E501

        :param id: The id of this IotGroupConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def group_name(self):
        """Gets the group_name of this IotGroupConfigOutput.  # noqa: E501

        分组名称  # noqa: E501

        :return: The group_name of this IotGroupConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this IotGroupConfigOutput.

        分组名称  # noqa: E501

        :param group_name: The group_name of this IotGroupConfigOutput.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    @property
    def level_code(self):
        """Gets the level_code of this IotGroupConfigOutput.  # noqa: E501

        层级编码 如: 00010001  # noqa: E501

        :return: The level_code of this IotGroupConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._level_code

    @level_code.setter
    def level_code(self, level_code):
        """Sets the level_code of this IotGroupConfigOutput.

        层级编码 如: 00010001  # noqa: E501

        :param level_code: The level_code of this IotGroupConfigOutput.  # noqa: E501
        :type: str
        """

        self._level_code = level_code

    @property
    def parent_level_code(self):
        """Gets the parent_level_code of this IotGroupConfigOutput.  # noqa: E501

        父级层级编码 0001 可空,空代表顶级  # noqa: E501

        :return: The parent_level_code of this IotGroupConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._parent_level_code

    @parent_level_code.setter
    def parent_level_code(self, parent_level_code):
        """Sets the parent_level_code of this IotGroupConfigOutput.

        父级层级编码 0001 可空,空代表顶级  # noqa: E501

        :param parent_level_code: The parent_level_code of this IotGroupConfigOutput.  # noqa: E501
        :type: str
        """

        self._parent_level_code = parent_level_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IotGroupConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IotGroupConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class StringPage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'page_index': 'int',
        'page_size': 'int',
        'list': 'list[str]',
        'total_count': 'int',
        'total_pages': 'int',
        'have_next_page': 'bool'
    }

    attribute_map = {
        'page_index': 'pageIndex',
        'page_size': 'pageSize',
        'list': 'list',
        'total_count': 'totalCount',
        'total_pages': 'totalPages',
        'have_next_page': 'haveNextPage'
    }

    def __init__(self, page_index=None, page_size=None, list=None, total_count=None, total_pages=None, have_next_page=None, local_vars_configuration=None):  # noqa: E501
        """StringPage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._page_index = None
        self._page_size = None
        self._list = None
        self._total_count = None
        self._total_pages = None
        self._have_next_page = None
        self.discriminator = None

        if page_index is not None:
            self.page_index = page_index
        if page_size is not None:
            self.page_size = page_size
        self.list = list
        if total_count is not None:
            self.total_count = total_count
        if total_pages is not None:
            self.total_pages = total_pages
        if have_next_page is not None:
            self.have_next_page = have_next_page

    @property
    def page_index(self):
        """Gets the page_index of this StringPage.  # noqa: E501


        :return: The page_index of this StringPage.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this StringPage.


        :param page_index: The page_index of this StringPage.  # noqa: E501
        :type: int
        """

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this StringPage.  # noqa: E501


        :return: The page_size of this StringPage.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this StringPage.


        :param page_size: The page_size of this StringPage.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def list(self):
        """Gets the list of this StringPage.  # noqa: E501


        :return: The list of this StringPage.  # noqa: E501
        :rtype: list[str]
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this StringPage.


        :param list: The list of this StringPage.  # noqa: E501
        :type: list[str]
        """

        self._list = list

    @property
    def total_count(self):
        """Gets the total_count of this StringPage.  # noqa: E501


        :return: The total_count of this StringPage.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this StringPage.


        :param total_count: The total_count of this StringPage.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    @property
    def total_pages(self):
        """Gets the total_pages of this StringPage.  # noqa: E501


        :return: The total_pages of this StringPage.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this StringPage.


        :param total_pages: The total_pages of this StringPage.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    @property
    def have_next_page(self):
        """Gets the have_next_page of this StringPage.  # noqa: E501


        :return: The have_next_page of this StringPage.  # noqa: E501
        :rtype: bool
        """
        return self._have_next_page

    @have_next_page.setter
    def have_next_page(self, have_next_page):
        """Sets the have_next_page of this StringPage.


        :param have_next_page: The have_next_page of this StringPage.  # noqa: E501
        :type: bool
        """

        self._have_next_page = have_next_page

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StringPage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StringPage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class RoleDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'remarks': 'str',
        'is_default': 'bool',
        'extra_properties': 'str',
        'creation_time': 'datetime',
        'creator_id': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'remarks': 'remarks',
        'is_default': 'isDefault',
        'extra_properties': 'extraProperties',
        'creation_time': 'creationTime',
        'creator_id': 'creatorId',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, name=None, remarks=None, is_default=None, extra_properties=None, creation_time=None, creator_id=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """RoleDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._remarks = None
        self._is_default = None
        self._extra_properties = None
        self._creation_time = None
        self._creator_id = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.remarks = remarks
        if is_default is not None:
            self.is_default = is_default
        self.extra_properties = extra_properties
        if creation_time is not None:
            self.creation_time = creation_time
        self.creator_id = creator_id
        self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this RoleDto.  # noqa: E501

        角色ID role id  # noqa: E501

        :return: The id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RoleDto.

        角色ID role id  # noqa: E501

        :param id: The id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this RoleDto.  # noqa: E501

        角色名称 role name  # noqa: E501

        :return: The name of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RoleDto.

        角色名称 role name  # noqa: E501

        :param name: The name of this RoleDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def remarks(self):
        """Gets the remarks of this RoleDto.  # noqa: E501

        角色备注 role remark  # noqa: E501

        :return: The remarks of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._remarks

    @remarks.setter
    def remarks(self, remarks):
        """Sets the remarks of this RoleDto.

        角色备注 role remark  # noqa: E501

        :param remarks: The remarks of this RoleDto.  # noqa: E501
        :type: str
        """

        self._remarks = remarks

    @property
    def is_default(self):
        """Gets the is_default of this RoleDto.  # noqa: E501

        是否为默认角色 if it is the default role  # noqa: E501

        :return: The is_default of this RoleDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this RoleDto.

        是否为默认角色 if it is the default role  # noqa: E501

        :param is_default: The is_default of this RoleDto.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def extra_properties(self):
        """Gets the extra_properties of this RoleDto.  # noqa: E501

        额外的属性 extra properties  # noqa: E501

        :return: The extra_properties of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._extra_properties

    @extra_properties.setter
    def extra_properties(self, extra_properties):
        """Sets the extra_properties of this RoleDto.

        额外的属性 extra properties  # noqa: E501

        :param extra_properties: The extra_properties of this RoleDto.  # noqa: E501
        :type: str
        """

        self._extra_properties = extra_properties

    @property
    def creation_time(self):
        """Gets the creation_time of this RoleDto.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The creation_time of this RoleDto.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this RoleDto.

        创建时间 create time  # noqa: E501

        :param creation_time: The creation_time of this RoleDto.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def creator_id(self):
        """Gets the creator_id of this RoleDto.  # noqa: E501

        创建者ID creator id  # noqa: E501

        :return: The creator_id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """Sets the creator_id of this RoleDto.

        创建者ID creator id  # noqa: E501

        :param creator_id: The creator_id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this RoleDto.  # noqa: E501

        租户ID tenant id  # noqa: E501

        :return: The tenant_id of this RoleDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this RoleDto.

        租户ID tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this RoleDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoleDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoleDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class QueryDemandDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'junction_id': 'str',
        'demand': 'float',
        'category': 'str',
        'coefficient': 'float',
        'pattern_id': 'str',
        'description': 'str',
        'id': 'str'
    }

    attribute_map = {
        'junction_id': 'junctionID',
        'demand': 'demand',
        'category': 'category',
        'coefficient': 'coefficient',
        'pattern_id': 'patternID',
        'description': 'description',
        'id': 'id'
    }

    def __init__(self, junction_id=None, demand=None, category=None, coefficient=None, pattern_id=None, description=None, id=None, local_vars_configuration=None):  # noqa: E501
        """QueryDemandDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._junction_id = None
        self._demand = None
        self._category = None
        self._coefficient = None
        self._pattern_id = None
        self._description = None
        self._id = None
        self.discriminator = None

        self.junction_id = junction_id
        if demand is not None:
            self.demand = demand
        self.category = category
        if coefficient is not None:
            self.coefficient = coefficient
        self.pattern_id = pattern_id
        self.description = description
        if id is not None:
            self.id = id

    @property
    def junction_id(self):
        """Gets the junction_id of this QueryDemandDto.  # noqa: E501

        模型中的节点ID junction muid  # noqa: E501

        :return: The junction_id of this QueryDemandDto.  # noqa: E501
        :rtype: str
        """
        return self._junction_id

    @junction_id.setter
    def junction_id(self, junction_id):
        """Sets the junction_id of this QueryDemandDto.

        模型中的节点ID junction muid  # noqa: E501

        :param junction_id: The junction_id of this QueryDemandDto.  # noqa: E501
        :type: str
        """

        self._junction_id = junction_id

    @property
    def demand(self):
        """Gets the demand of this QueryDemandDto.  # noqa: E501

        需水量或需水量增量 demand or demand difference  # noqa: E501

        :return: The demand of this QueryDemandDto.  # noqa: E501
        :rtype: float
        """
        return self._demand

    @demand.setter
    def demand(self, demand):
        """Sets the demand of this QueryDemandDto.

        需水量或需水量增量 demand or demand difference  # noqa: E501

        :param demand: The demand of this QueryDemandDto.  # noqa: E501
        :type: float
        """

        self._demand = demand

    @property
    def category(self):
        """Gets the category of this QueryDemandDto.  # noqa: E501

        分类 category  # noqa: E501

        :return: The category of this QueryDemandDto.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this QueryDemandDto.

        分类 category  # noqa: E501

        :param category: The category of this QueryDemandDto.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def coefficient(self):
        """Gets the coefficient of this QueryDemandDto.  # noqa: E501

        系数 coefficient  # noqa: E501

        :return: The coefficient of this QueryDemandDto.  # noqa: E501
        :rtype: float
        """
        return self._coefficient

    @coefficient.setter
    def coefficient(self, coefficient):
        """Sets the coefficient of this QueryDemandDto.

        系数 coefficient  # noqa: E501

        :param coefficient: The coefficient of this QueryDemandDto.  # noqa: E501
        :type: float
        """

        self._coefficient = coefficient

    @property
    def pattern_id(self):
        """Gets the pattern_id of this QueryDemandDto.  # noqa: E501

        模式ID pattern id  # noqa: E501

        :return: The pattern_id of this QueryDemandDto.  # noqa: E501
        :rtype: str
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """Sets the pattern_id of this QueryDemandDto.

        模式ID pattern id  # noqa: E501

        :param pattern_id: The pattern_id of this QueryDemandDto.  # noqa: E501
        :type: str
        """

        self._pattern_id = pattern_id

    @property
    def description(self):
        """Gets the description of this QueryDemandDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this QueryDemandDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryDemandDto.

        描述 description  # noqa: E501

        :param description: The description of this QueryDemandDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this QueryDemandDto.  # noqa: E501

        需水量ID demand id  # noqa: E501

        :return: The id of this QueryDemandDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryDemandDto.

        需水量ID demand id  # noqa: E501

        :param id: The id of this QueryDemandDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryDemandDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryDemandDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class BuildCalcDosageConfigInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'param': 'str',
        'sys_code': 'str',
        'ext_info': 'str',
        'category': 'int',
        'action': 'str',
        'code': 'str',
        'point_type': 'str',
        'is_input_point': 'bool',
        'product_line': 'str'
    }

    attribute_map = {
        'id': 'id',
        'param': 'param',
        'sys_code': 'sysCode',
        'ext_info': 'extInfo',
        'category': 'category',
        'action': 'action',
        'code': 'code',
        'point_type': 'pointType',
        'is_input_point': 'isInputPoint',
        'product_line': 'productLine'
    }

    def __init__(self, id=None, param=None, sys_code=None, ext_info=None, category=None, action=None, code=None, point_type=None, is_input_point=None, product_line=None, local_vars_configuration=None):  # noqa: E501
        """BuildCalcDosageConfigInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._param = None
        self._sys_code = None
        self._ext_info = None
        self._category = None
        self._action = None
        self._code = None
        self._point_type = None
        self._is_input_point = None
        self._product_line = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.param = param
        self.sys_code = sys_code
        self.ext_info = ext_info
        if category is not None:
            self.category = category
        self.action = action
        self.code = code
        self.point_type = point_type
        if is_input_point is not None:
            self.is_input_point = is_input_point
        self.product_line = product_line

    @property
    def id(self):
        """Gets the id of this BuildCalcDosageConfigInOut.  # noqa: E501

        配置ID config id  # noqa: E501

        :return: The id of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BuildCalcDosageConfigInOut.

        配置ID config id  # noqa: E501

        :param id: The id of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def param(self):
        """Gets the param of this BuildCalcDosageConfigInOut.  # noqa: E501

        参数名 parameter name  # noqa: E501

        :return: The param of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._param

    @param.setter
    def param(self, param):
        """Sets the param of this BuildCalcDosageConfigInOut.

        参数名 parameter name  # noqa: E501

        :param param: The param of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._param = param

    @property
    def sys_code(self):
        """Gets the sys_code of this BuildCalcDosageConfigInOut.  # noqa: E501

        系统代码 system code  # noqa: E501

        :return: The sys_code of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._sys_code

    @sys_code.setter
    def sys_code(self, sys_code):
        """Sets the sys_code of this BuildCalcDosageConfigInOut.

        系统代码 system code  # noqa: E501

        :param sys_code: The sys_code of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._sys_code = sys_code

    @property
    def ext_info(self):
        """Gets the ext_info of this BuildCalcDosageConfigInOut.  # noqa: E501

        生化池序号 biochemical pool index  # noqa: E501

        :return: The ext_info of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._ext_info

    @ext_info.setter
    def ext_info(self, ext_info):
        """Sets the ext_info of this BuildCalcDosageConfigInOut.

        生化池序号 biochemical pool index  # noqa: E501

        :param ext_info: The ext_info of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._ext_info = ext_info

    @property
    def category(self):
        """Gets the category of this BuildCalcDosageConfigInOut.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this BuildCalcDosageConfigInOut.

        药剂投加类别  # noqa: E501

        :param category: The category of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def action(self):
        """Gets the action of this BuildCalcDosageConfigInOut.  # noqa: E501

        该参数用途 parameter usage  # noqa: E501

        :return: The action of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this BuildCalcDosageConfigInOut.

        该参数用途 parameter usage  # noqa: E501

        :param action: The action of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def code(self):
        """Gets the code of this BuildCalcDosageConfigInOut.  # noqa: E501

        系统点位编码 system point code  # noqa: E501

        :return: The code of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this BuildCalcDosageConfigInOut.

        系统点位编码 system point code  # noqa: E501

        :param code: The code of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def point_type(self):
        """Gets the point_type of this BuildCalcDosageConfigInOut.  # noqa: E501

        点位类型 point type  # noqa: E501

        :return: The point_type of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._point_type

    @point_type.setter
    def point_type(self, point_type):
        """Sets the point_type of this BuildCalcDosageConfigInOut.

        点位类型 point type  # noqa: E501

        :param point_type: The point_type of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._point_type = point_type

    @property
    def is_input_point(self):
        """Gets the is_input_point of this BuildCalcDosageConfigInOut.  # noqa: E501

        是否为输入点位 if it is an online point for input  # noqa: E501

        :return: The is_input_point of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: bool
        """
        return self._is_input_point

    @is_input_point.setter
    def is_input_point(self, is_input_point):
        """Sets the is_input_point of this BuildCalcDosageConfigInOut.

        是否为输入点位 if it is an online point for input  # noqa: E501

        :param is_input_point: The is_input_point of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: bool
        """

        self._is_input_point = is_input_point

    @property
    def product_line(self):
        """Gets the product_line of this BuildCalcDosageConfigInOut.  # noqa: E501

        生产线代码 product line code  # noqa: E501

        :return: The product_line of this BuildCalcDosageConfigInOut.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this BuildCalcDosageConfigInOut.

        生产线代码 product line code  # noqa: E501

        :param product_line: The product_line of this BuildCalcDosageConfigInOut.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BuildCalcDosageConfigInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BuildCalcDosageConfigInOut):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class MenuPerTree(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'label': 'str',
        'is_check': 'bool',
        'menu_router': 'str',
        'regular': 'str',
        'api_regular': 'str',
        'children': 'list[MenuPerTree]'
    }

    attribute_map = {
        'id': 'id',
        'label': 'label',
        'is_check': 'isCheck',
        'menu_router': 'menuRouter',
        'regular': 'regular',
        'api_regular': 'apiRegular',
        'children': 'children'
    }

    def __init__(self, id=None, label=None, is_check=None, menu_router=None, regular=None, api_regular=None, children=None, local_vars_configuration=None):  # noqa: E501
        """MenuPerTree - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._label = None
        self._is_check = None
        self._menu_router = None
        self._regular = None
        self._api_regular = None
        self._children = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.label = label
        if is_check is not None:
            self.is_check = is_check
        self.menu_router = menu_router
        self.regular = regular
        self.api_regular = api_regular
        self.children = children

    @property
    def id(self):
        """Gets the id of this MenuPerTree.  # noqa: E501

        菜单Id menu id  # noqa: E501

        :return: The id of this MenuPerTree.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MenuPerTree.

        菜单Id menu id  # noqa: E501

        :param id: The id of this MenuPerTree.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def label(self):
        """Gets the label of this MenuPerTree.  # noqa: E501

        菜单名称 menu label  # noqa: E501

        :return: The label of this MenuPerTree.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this MenuPerTree.

        菜单名称 menu label  # noqa: E501

        :param label: The label of this MenuPerTree.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def is_check(self):
        """Gets the is_check of this MenuPerTree.  # noqa: E501

        是否选中状态 if it is checked  # noqa: E501

        :return: The is_check of this MenuPerTree.  # noqa: E501
        :rtype: bool
        """
        return self._is_check

    @is_check.setter
    def is_check(self, is_check):
        """Sets the is_check of this MenuPerTree.

        是否选中状态 if it is checked  # noqa: E501

        :param is_check: The is_check of this MenuPerTree.  # noqa: E501
        :type: bool
        """

        self._is_check = is_check

    @property
    def menu_router(self):
        """Gets the menu_router of this MenuPerTree.  # noqa: E501

        菜单路由  # noqa: E501

        :return: The menu_router of this MenuPerTree.  # noqa: E501
        :rtype: str
        """
        return self._menu_router

    @menu_router.setter
    def menu_router(self, menu_router):
        """Sets the menu_router of this MenuPerTree.

        菜单路由  # noqa: E501

        :param menu_router: The menu_router of this MenuPerTree.  # noqa: E501
        :type: str
        """

        self._menu_router = menu_router

    @property
    def regular(self):
        """Gets the regular of this MenuPerTree.  # noqa: E501

        按钮路由  # noqa: E501

        :return: The regular of this MenuPerTree.  # noqa: E501
        :rtype: str
        """
        return self._regular

    @regular.setter
    def regular(self, regular):
        """Sets the regular of this MenuPerTree.

        按钮路由  # noqa: E501

        :param regular: The regular of this MenuPerTree.  # noqa: E501
        :type: str
        """

        self._regular = regular

    @property
    def api_regular(self):
        """Gets the api_regular of this MenuPerTree.  # noqa: E501

        后端API权限规则  # noqa: E501

        :return: The api_regular of this MenuPerTree.  # noqa: E501
        :rtype: str
        """
        return self._api_regular

    @api_regular.setter
    def api_regular(self, api_regular):
        """Sets the api_regular of this MenuPerTree.

        后端API权限规则  # noqa: E501

        :param api_regular: The api_regular of this MenuPerTree.  # noqa: E501
        :type: str
        """

        self._api_regular = api_regular

    @property
    def children(self):
        """Gets the children of this MenuPerTree.  # noqa: E501

        子菜单 sub menus  # noqa: E501

        :return: The children of this MenuPerTree.  # noqa: E501
        :rtype: list[MenuPerTree]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this MenuPerTree.

        子菜单 sub menus  # noqa: E501

        :param children: The children of this MenuPerTree.  # noqa: E501
        :type: list[MenuPerTree]
        """

        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MenuPerTree):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MenuPerTree):
            return True

        return self.to_dict() != other.to_dict()
